@@ -199,8 +199,10 @@ screen:
       - Vulnerability State
       - Vulnerability Port
       - Vulnerability Protocol
+      - Patch Publication Date
     Asset:
       - Tenable Asset UUID
+      - Tenable Asset Tags
       - Tenable Platform
       - Device Hostname
       - Device NetBIOS Name
@@ -283,7 +285,7 @@ fields:
   - jira_field: Patch Publication Date
     type: readonlyfield
     searcher: textsearcher
-    issuetype:
+    issue_type:
       - Task
       - Sub-task
     tio_field: plugin.patch_publication_date
@@ -333,6 +335,13 @@ fields:
       - Sub-task
     tio_field: asset.uuid
 
+  - jira_field: Tenable Asset Tags
+    type: labels
+    searcher: labelsearcher
+    issue_type:
+      - Sub-task
+    is_tio_tags: true
+
   - jira_field: Device MAC Addresses
     type: readonlyfield
     searcher: textsearcher
